/*
	Project: The fragility of artists’ reputations from 1795 to 2020 (2023)
	Author: Letian Zhang et al.
	
	Description: Master do file that runs all tables and figures for the project
*/

**************************** Final Data Construction *****************************************
gen painter=occupation=="PAINTER"
gen musician=occupation=="MUSICIAN"
gen composer=occupation=="COMPOSER"
gen musiciancomposer=max(musician, composer)
gen writer=occupation=="WRITER"
gen director=occupation=="FILM DIRECTOR"
gen other_artist=0
replace other_artist=1 if artist==1 & painter==0 & musician==0 & composer==0 & writer==0 & director==0
gen reputation = stdcompetent_20_10
gen sample=0
replace sample=1 if year_after_death>-40 & year_after_death<120  & artist==1 & news_occurrence>2 & pct_dead<1 & pct_dead>0
replace sample=0 if name=="The Rev" | name=="Dr. Seuss" | (name=="Michael Jackson" & occupation=="WRITER")
gen sample3=0
replace sample3=1 if year_after_death>-40 & year_after_death<220  & artist==1 & pct_dead<1 & pct_dead>0
replace sample3=0 if name=="The Rev" | name=="Dr. Seuss" | (name=="Michael Jackson" & occupation=="WRITER")
*Figure 1(a)-1(e)
foreach var of varlist artist painter musiciancomposer writer  other_artist {
areg reputation year_after_death_m5-year_after_death_m30 year_after_death_10-year_after_death_200 if `var'==1 & sample==1, a(id_final) cluster(id_final)
	drop tp tp_se tp_year tp_se1 tp_se2
	gen tp=.
	gen tp_se=.
	gen tp_year=.
	gen tp_se1=.
	gen tp_se2=.

	foreach x of numlist 10(10)200 {
	replace tp=_b[year_after_death_`x'] if _n==`x'
	replace tp_se=_se[year_after_death_`x'] if _n==`x'
	replace tp_year=`x' if _n==`x'
	}
	foreach x of numlist 5(5)30 {
	replace tp=_b[year_after_death_m`x'] if _n==1000+`x'
	replace tp_se=_se[year_after_death_m`x'] if _n==1000+`x'
	replace tp_year=-`x' if _n==1000+`x'
	}

	replace tp=0 if _n==1000
	replace tp_year=0 if _n==1000
	replace tp_se1=tp+1.96*tp_se
	replace tp_se2=tp-1.96*tp_se

	twoway (connected tp tp_year if tp_year<101, lc(black) mc(black)  msymbol(o) sort) (rcap tp_se1 tp_se2 tp_year if tp_year<101, lc(black) mc(black)), ///
	xlabel(-30(20)100, labsize(large)) xline(0, lcolor(black) lpattern(dash)) yline(0, lcolor(black) lpattern(dash)) graphregion(color(white)) legend(off) graphregion(color(white)) ///
	xtitle("Years after Death", size(large)) ytitle("Estimated Reputation", size(medlarge)) ylabel(-1 1,labsize(large))
	graph export graph_predicted_`var'.eps, replace
}



*Figure 2
drop reputation_initial
drop valid
gen valid=reputation~=.
gsort valid id_final dead -year2 
by valid id_final dead: gen reputation_initial=reputation[1] if dead==0 & valid==1
gsort valid id_final reputation_initial
by valid id_final: replace reputation_initial=reputation_initial[1] if reputation_initial==. & valid==1

*drop tp1 tp1_se tp1_se1 tp1_se2 tp2 tp2_se tp2_se1 tp2_se2
*drop tp_year
	gen tp_year=.
	gen tp1=.
	gen tp1_se=.
	gen tp1_se1=.
	gen tp1_se2=.
	gen tp2=.
	gen tp2_se=.
	gen tp2_se1=.
	gen tp2_se2=.
areg reputation year_after_death_m5-year_after_death_m30 year_after_death_10-year_after_death_200 if sample==1, a(id_final) cluster(id_final)
sum reputation_initial if e(sample)==1 & year_after_death_0==1, detail
su reputation_initial if reputation_initial<-0.24 & year_after_death_0==1 & e(sample)==1
gen constant1=-0.85
areg reputation year_after_death_m5-year_after_death_m30 year_after_death_10-year_after_death_200  if reputation_initial<-0.32  & artist==1, a(id_final) cluster(id_final)
	
	foreach x of numlist 10(10)200 {
	replace tp1=_b[year_after_death_`x']+constant1 if _n==`x'
	replace tp1_se=_se[year_after_death_`x'] if _n==`x'
	replace tp_year=`x' if _n==`x'
	}
	foreach x of numlist 5(5)30 {
	replace tp1=_b[year_after_death_m`x']+constant1 if _n==1000+`x'
	replace tp1_se=_se[year_after_death_m`x'] if _n==1000+`x'
	replace tp_year=-`x' if _n==1000+`x'
	}

	replace tp1=constant1 if _n==1000
	replace tp1_se1=tp1+1.96*tp1_se
	replace tp1_se2=tp1-1.96*tp1_se
	replace tp_year=0 if _n==1000
drop constant1

su reputation_initial if reputation_initial>1.07 & year_after_death_0==1 & e(sample)==1
gen constant2=1.58
areg reputation year_after_death_m5-year_after_death_m30 year_after_death_10-year_after_death_200  if reputation_initial>1.1 & reputation_initial~=.  & artist==1, a(id_final) cluster(id_final)
	
	foreach x of numlist 10(10)200 {
	replace tp2=_b[year_after_death_`x']+constant2 if _n==`x'
	replace tp2_se=_se[year_after_death_`x'] if _n==`x'
	}
	foreach x of numlist 5(5)30 {
	replace tp2=_b[year_after_death_m`x']+constant2 if _n==1000+`x'
	replace tp2_se=_se[year_after_death_m`x'] if _n==1000+`x'
	}

	replace tp2=constant2  if _n==1000
	replace tp2_se1=tp2+1.96*tp2_se
	replace tp2_se2=tp2-1.96*tp2_se
	drop constant2
	
twoway (connected tp1 tp2 tp_year if tp_year<101, mcolor(gs8 gs0) lcolor(gs8 gs0)  msymbol(o s) sort) (rcap tp1_se1 tp1_se2 tp_year if tp_year<101, lc(gs8) mc(gs8))  (rcap tp2_se1 tp2_se2 tp_year if tp_year<101, lc(gs0) mc(gs0)) , ///
xlabel(-30(20)100, labsize(large)) xline(0, lcolor(black) lpattern(dash)) yline(0, lcolor(black) lpattern(dash)) graphregion(color(white)) legend(order(1 "Lower Initial Reputation" 2 "Higher Initial Reputation") size(medium) symxsize(medium)) graphregion(color(white)) ///
xtitle("Years after Death", size(large)) ytitle("Estimated Reputation", size(medlarge)) ylabel(-3 3,labsize(large))
graph export graph_predicted_inital_artist.eps, replace

*Figure 3(a)-3(b)
drop tp1 tp1_se tp1_se1 tp1_se2 tp2 tp2_se tp2_se1 tp2_se2
drop tp_year
	gen tp_year=.
	gen tp1=.
	gen tp1_se=.
	gen tp1_se1=.
	gen tp1_se2=.
	gen tp2=.
	gen tp2_se=.
	gen tp2_se1=.
	gen tp2_se2=.
gen constant1=0
areg reputation year_after_death_m5-year_after_death_m30 year_after_death_10-year_after_death_200  if age_death<41 & sample==1 & artist==1, a(id_final) cluster(id_final)
	
	foreach x of numlist 10(10)200 {
	replace tp1=_b[year_after_death_`x']+constant1 if _n==`x'
	replace tp1_se=_se[year_after_death_`x'] if _n==`x'
	replace tp_year=`x' if _n==`x'
	}
	foreach x of numlist 5(5)30 {
	replace tp1=_b[year_after_death_m`x']+constant1 if _n==1000+`x'
	replace tp1_se=_se[year_after_death_m`x'] if _n==1000+`x'
	replace tp_year=-`x' if _n==1000+`x'
	}

	replace tp1=constant1 if _n==1000
	replace tp1_se1=tp1+1.96*tp1_se
	replace tp1_se2=tp1-1.96*tp1_se
	replace tp_year=0 if _n==1000
drop constant1

gen constant2=0
areg reputation year_after_death_m5-year_after_death_m30 year_after_death_10-year_after_death_200  if age_death>70 & age_death~=. & sample==1, a(id_final) cluster(id_final)
	
	foreach x of numlist 10(10)200 {
	replace tp2=_b[year_after_death_`x']+constant2 if _n==`x'
	replace tp2_se=_se[year_after_death_`x'] if _n==`x'
	}
	foreach x of numlist 5(5)30 {
	replace tp2=_b[year_after_death_m`x']+constant2 if _n==1000+`x'
	replace tp2_se=_se[year_after_death_m`x'] if _n==1000+`x'
	}

	replace tp2=constant2  if _n==1000
	replace tp2_se1=tp2+1.96*tp2_se
	replace tp2_se2=tp2-1.96*tp2_se
	drop constant2
	
twoway (connected tp1 tp2 tp_year if tp_year<101, mcolor(gs8 gs0) lcolor(gs8 gs0)  msymbol(o s) sort) (rcap tp1_se1 tp1_se2 tp_year if tp_year<101, lc(gs8) mc(gs8))  (rcap tp2_se1 tp2_se2 tp_year if tp_year<101, lc(gs0) mc(gs0)) , ///
xlabel(-30(20)100, labsize(large)) xline(0, lcolor(black) lpattern(dash)) yline(0, lcolor(black) lpattern(dash)) graphregion(color(white)) legend(order(1 "Age of Death < 40" 2 "Age of Death > 70") size(medium) symxsize(medium)) graphregion(color(white)) ///
xtitle("Years after Death", size(large)) ytitle("Estimated Reputation", size(medlarge)) ylabel(-1 1,labsize(large))
	
	graph export graph_predicted_age_death.eps, replace
	
	
	
drop tp1 tp1_se tp1_se1 tp1_se2 tp2 tp2_se tp2_se1 tp2_se2
drop tp_year
	gen tp_year=.
	gen tp1=.
	gen tp1_se=.
	gen tp1_se1=.
	gen tp1_se2=.
	gen tp2=.
	gen tp2_se=.
	gen tp2_se1=.
	gen tp2_se2=.
gen constant1=0
areg reputation year_after_death_m5-year_after_death_m30 year_after_death_10-year_after_death_200  if expected_death==4 & sample==1 & artist==1, a(id_final) cluster(id_final)
	
	foreach x of numlist 10(10)200 {
	replace tp1=_b[year_after_death_`x']+constant1 if _n==`x'
	replace tp1_se=_se[year_after_death_`x'] if _n==`x'
	replace tp_year=`x' if _n==`x'
	}
	foreach x of numlist 5(5)30 {
	replace tp1=_b[year_after_death_m`x']+constant1 if _n==1000+`x'
	replace tp1_se=_se[year_after_death_m`x'] if _n==1000+`x'
	replace tp_year=-`x' if _n==1000+`x'
	}

	replace tp1=constant1 if _n==1000
	replace tp1_se1=tp1+1.96*tp1_se
	replace tp1_se2=tp1-1.96*tp1_se
	replace tp_year=0 if _n==1000
drop constant1

gen constant2=0 
areg reputation year_after_death_m5-year_after_death_m30 year_after_death_10-year_after_death_200  if expected_death==2 & artist==1 & sample==1, a(id_final) cluster(id_final)
	
	foreach x of numlist 10(10)200 {
	replace tp2=_b[year_after_death_`x']+constant2 if _n==`x'
	replace tp2_se=_se[year_after_death_`x'] if _n==`x'
	}
	foreach x of numlist 5(5)30 {
	replace tp2=_b[year_after_death_m`x']+constant2 if _n==1000+`x'
	replace tp2_se=_se[year_after_death_m`x'] if _n==1000+`x'
	}

	replace tp2=constant2  if _n==1000
	replace tp2_se1=tp2+1.96*tp2_se
	replace tp2_se2=tp2-1.96*tp2_se
	drop constant2
	
twoway (connected tp1 tp2 tp_year if tp_year<101, mcolor(gs8 gs0) lcolor(gs8 gs0)  msymbol(o s) sort) (rcap tp1_se1 tp1_se2 tp_year if tp_year<101, lc(gs8) mc(gs8))  (rcap tp2_se1 tp2_se2 tp_year if tp_year<101, lc(gs0) mc(gs0)) , ///
xlabel(-30(20)100, labsize(large)) xline(0, lcolor(black) lpattern(dash)) yline(0, lcolor(black) lpattern(dash)) graphregion(color(white)) legend(order(1 "Unexpected Death" 2 "Natural Death") size(medium) symxsize(medium)) graphregion(color(white)) ///
xtitle("Years after Death", size(large)) ytitle("Estimated Reputation", size(medlarge)) ylabel(-1 1,labsize(large))
	
	graph export graph_predicted_unexpected_death.eps, replace

	
*Figure 4
drop famous_after_death
gen famous_after_death=1 if pct_dead>0 & pct_dead<1 
replace famous_after_death=0 if news_occurrence>4 & nondead==1
gsort id_final famous_after_death
by id_final: replace famous_after_death=famous_after_death[1]

bys id_final: egen delete=total(valid)
replace famous_after_death=. if delete<3
drop delete

areg reputation year_after_death_m5-year_after_death_m30 year_after_death_10-year_after_death_200 if artist==1 & famous_after_death==1, a(id_final) cluster(id_final)
	drop tp tp_se tp_year tp_se1 tp_se2
	gen tp=.
	gen tp_se=.
	gen tp_year=.
	gen tp_se1=.
	gen tp_se2=.

	foreach x of numlist 10(10)200 {
	replace tp=_b[year_after_death_`x'] if _n==`x'
	replace tp_se=_se[year_after_death_`x'] if _n==`x'
	replace tp_year=`x' if _n==`x'
	}
	foreach x of numlist 5(5)30 {
	replace tp=_b[year_after_death_m`x'] if _n==1000+`x'
	replace tp_se=_se[year_after_death_m`x'] if _n==1000+`x'
	replace tp_year=-`x' if _n==1000+`x'
	}

	replace tp=0 if _n==1000
	replace tp_year=0 if _n==1000
	replace tp_se1=tp+1.96*tp_se
	replace tp_se2=tp-1.96*tp_se

	twoway (connected tp tp_year if tp_year>-1 & tp_year<201, lc(black) mc(black)  msymbol(o) sort) (rcap tp_se1 tp_se2 tp_year if tp_year>-1 & tp_year<201, lc(black) mc(black)), ///
	xlabel(0(20)200, labsize(large)) xline(0, lcolor(black) lpattern(dash)) yline(0, lcolor(black) lpattern(dash)) graphregion(color(white)) legend(off) graphregion(color(white)) ///
	xtitle("Years after Death", size(large)) ytitle("Estimated Reputation", size(medlarge)) ylabel(-1 1,labsize(large))
	graph export graph_famous_after_death.eps, replace

*Figure 5(a)-5(b)
drop valid_newspaper
gen valid_newspaper=(newspaper_count~=.)
replace valid_newspaper=0 if deathyear>2010
gsort -valid_newspaper -artist -year2 -newspaper_count
tab year2
gen delete=0
replace delete=1 if _n<61

gsort id_final -delete
by id_final: replace delete=delete[1]

areg reputation year_after_death_m5-year_after_death_m30 year_after_death_10-year_after_death_200  if delete==1 & artist==1 & sample==1, a(id_final) cluster(id_final)
	drop tp tp_se tp_year tp_se1 tp_se2
	gen tp=.
	gen tp_se=.
	gen tp_year=.
	gen tp_se1=.
	gen tp_se2=.

	foreach x of numlist 10(10)200 {
	replace tp=_b[year_after_death_`x'] if _n==`x'
	replace tp_se=_se[year_after_death_`x'] if _n==`x'
	replace tp_year=`x' if _n==`x'
	}
	foreach x of numlist 5(5)30 {
	replace tp=_b[year_after_death_m`x'] if _n==1000+`x'
	replace tp_se=_se[year_after_death_m`x'] if _n==1000+`x'
	replace tp_year=-`x' if _n==1000+`x'
	}

	replace tp=0 if _n==1000
	replace tp_year=0 if _n==1000
	replace tp_se1=tp+1.96*tp_se
	replace tp_se2=tp-1.96*tp_se

	twoway (connected tp tp_year if tp_year<101, lc(black) mc(black)  msymbol(o) sort) (rcap tp_se1 tp_se2 tp_year if tp_year<101, lc(black) mc(black)), ///
	xlabel(-30(20)100, labsize(large)) xline(0, lcolor(black) lpattern(dash)) ylabel(-1(0.5)1) yline(0, lcolor(black) lpattern(dash)) graphregion(color(white)) legend(off) graphregion(color(white)) ///
	xtitle("Years after Death", size(large)) ytitle("Estimated Reputation", size(medlarge)) ylabel(,labsize(large))
	graph export graph_most_popular_today_top50.eps, replace
	
	
	
drop  valid_newspaper
gen valid_newspaper=(newspaper_count~=.)
replace valid_newspaper=0 if deathyear>2010
gsort -valid_newspaper -artist -year2 -newspaper_count
tab year2
gen delete=0
replace delete=1 if _n<547

gsort id_final -delete
by id_final: replace delete=delete[1]

areg reputation year_after_death_m5-year_after_death_m30 year_after_death_10-year_after_death_200  if delete==1 & artist==1 & sample==1, a(id_final) cluster(id_final)
	drop tp tp_se tp_year tp_se1 tp_se2
	gen tp=.
	gen tp_se=.
	gen tp_year=.
	gen tp_se1=.
	gen tp_se2=.

	foreach x of numlist 10(10)200 {
	replace tp=_b[year_after_death_`x'] if _n==`x'
	replace tp_se=_se[year_after_death_`x'] if _n==`x'
	replace tp_year=`x' if _n==`x'
	}
	foreach x of numlist 5(5)30 {
	replace tp=_b[year_after_death_m`x'] if _n==1000+`x'
	replace tp_se=_se[year_after_death_m`x'] if _n==1000+`x'
	replace tp_year=-`x' if _n==1000+`x'
	}

	replace tp=0 if _n==1000
	replace tp_year=0 if _n==1000
	replace tp_se1=tp+1.96*tp_se
	replace tp_se2=tp-1.96*tp_se

	twoway (connected tp tp_year if tp_year<101, lc(black) mc(black)  msymbol(o) sort) (rcap tp_se1 tp_se2 tp_year if tp_year<101, lc(black) mc(black)), ///
	xlabel(-30(20)100, labsize(large)) xline(0, lcolor(black) lpattern(dash)) ylabel(-1(0.5)1) yline(0, lcolor(black) lpattern(dash)) graphregion(color(white)) legend(off) graphregion(color(white)) ///
	xtitle("Years after Death", size(large)) ytitle("Estimated Reputation", size(medlarge)) ylabel(,labsize(large))
	graph export graph_most_popular_today_top500.eps, replace
